@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """On 'the N word'.
 
 ---
@@ -17,10 +16,10 @@ from proselint.tools import existence_check, memoize
 
 
 @memoize
-def check_repeated_exclamations(text):
+def check(text):
     """Check the text."""
     err = "cursing.nword"
-    msg = u"Take responsibility for the shitty words you want to say."
+    msg = "Take responsibility for the shitty words you want to say."
 
     list = [
         "the n-word",
