@@ -20,12 +20,9 @@ from proselint.tools import existence_check, memoize
 def check(text):
     """Check the text."""
     err = "lexical_illusions.misc"
-    msg = u"There's a lexical illusion here: a word is repeated."
+    msg = "There's a lexical illusion here: a word is repeated."
+    regex = r"\b(\w+)(\b\s\1)+\b"
+    exceptions = [r"^had had$", r"^that that$"]
 
-    list = [
-        "the\sthe",
-        "am\sam",
-        "has\shas"
-    ]
-
-    return existence_check(text, list, err, msg)
+    return existence_check(text, [regex], err, msg, exceptions=exceptions,
+                           require_padding=False)
