@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Bureaucratese.
 
 ---
@@ -20,7 +19,7 @@ from proselint.tools import existence_check, memoize
 def check(text):
     """Check the text."""
     err = "misc.bureaucratese"
-    msg = u"'{}' is bureaucratese."
+    msg = "'{}' is bureaucratese."
 
     bureaucratese = [
         "meet with your approval",
