@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Phrasal adjectives.
 
 ---
@@ -13,25 +12,28 @@ categories: writing
 Phrasal adjectives.
 
 """
-from proselint.tools import existence_check, preferred_forms_check, memoize
+from proselint.tools import existence_check, memoize, preferred_forms_check
 
 
 @memoize
 def check_ly(text):
     """Check the text."""
     err = "garner.phrasal_adjectives.ly"
-    msg = u"""No hyphen is necessary in phrasal adjectives with an adverb
-              ending in -ly."""
+    msg = """No hyphen is necessary in phrasal adjectives with an adverb
+              ending in -ly, unless the -ly adverb is part of a longer
+              phrase"""
 
-    return existence_check(text, ["ly-"], err, msg,
+    regex = r"\s[^\s-]+ly-"
+
+    return existence_check(text, [regex], err, msg,
                            require_padding=False, offset=-1)
 
 
 @memoize
-def check_examples(text):
+def check(text):
     """Check the text."""
     err = "garner.phrasal_adjectives.examples"
-    msg = u"""Hyphenate '{1}', a phrasal adjective, as '{0}'."""
+    msg = """Hyphenate '{1}', a phrasal adjective, as '{0}'."""
 
     list = [
         ["across-the-board discounts", ["across the board discounts"]],
