@@ -1,10 +1,9 @@
 """Tests for misc.but check."""
-from __future__ import absolute_import
-
-from .check import Check
 
 from proselint.checks.misc import but as chk
 
+from .check import Check
+
 
 class TestCheck(Check):
     """The test class for misc.but."""
@@ -20,3 +19,5 @@ class TestCheck(Check):
         """Basic smoke test for misc.but."""
         assert self.passes("""Smoke phrase with nothing flagged.""")
         assert not self.passes("""But I never start with the word "but".""")
+        assert self.passes("""I never start with the word "but",
+but might use it after a linebreak.""")
