@@ -1,10 +1,9 @@
 """Test the preferred_forms_check function from the tools.py module."""
-from __future__ import absolute_import
-
-from .check import Check
 
 from proselint.tools import preferred_forms_check as chk
 
+from .check import Check
+
 
 class TestCheck(Check):
     """The test class for tools.preferred_forms_check."""
@@ -18,7 +17,7 @@ class TestCheck(Check):
 
     def setUp(self):
         """Create some test fixtures."""
-        self.l = [['use', ['utilize']]]
+        self.L = [['use', ['utilize']]]
         self.l_caps = [["Stone Age",  ["stone age"]]]
         self.err = 'error message'
         self.msg = 'use the preferred form'
@@ -26,9 +25,9 @@ class TestCheck(Check):
     def test_smoke(self):
         """Basic smoke test for preferred_forms_check."""
         assert chk(
-            "We utilize this tech", self.l, self.err, self.msg) != []
+            "We utilize this tech", self.L, self.err, self.msg) != []
         assert chk(
-            "We use this tech", self.l, self.err, self.msg) == []
+            "We use this tech", self.L, self.err, self.msg) == []
 
     def test_capitalization(self):
         """Test for preferred forms involving capitalization."""
